@@ -3,7 +3,7 @@ from paver.setuputils import setup
 
 options = environment.options
 
-VERSION = '0.1'
+VERSION = '0.2'
 
 setup(
     name='blackbelt',
@@ -13,11 +13,12 @@ setup(
     author='Lukas Linhart',
     author_email='lukas@apiary.io',
     url='http://github.com/apiaryio/black-belt',
+    license='MIT',
     packages=['blackbelt'],
-    tests_require=['nose', 'virtualenv', 'mock', 'cogapp'],
+    tests_require=['nose', 'virtualenv'],
     classifiers=[
         "Intended Audience :: Developers",
-        "License :: OSI Approved :: BSD License",
+        "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
         "Programming Language :: Python",
         "Programming Language :: Python :: 2",
